@@ -93,29 +93,33 @@ def test_trimesh(pyi_builder):
 def test_apscheduler(pyi_builder):
     pyi_builder.test_source(
         """
-        import apscheduler
-        import pytz
         import asyncio
+        import datetime
         import random
-        import datetime as dt
+        import time
+
         from apscheduler.schedulers.asyncio import AsyncIOScheduler
-        from apscheduler.triggers.interval import IntervalTrigger
-        loop = asyncio.get_event_loop()
-        async def test_function(data=0):
-            print(dt.datetime.now(), random.randint(0, 100))
-        test_scheduler = AsyncIOScheduler()
-        test_scheduler.add_job(
-            test_function,
-            id="TestJob",
-            trigger=IntervalTrigger(
-                seconds=1,
-                start_date=dt.datetime.now(tz=pytz.UTC)
-            )
-        )
-        test_scheduler.start()
-        loop.run_until_complete(asyncio.sleep(5))
-    """
-    )
+
+
+        def tick():
+            now = datetime.datetime.now(tz=datetime.timezone.utc)
+            value = random.randint(0, 100)
+            print(f"Tick! Current time is: {now}, random value: {value}")
+
+
+        async def main():
+            scheduler = AsyncIOScheduler()
+            scheduler.add_job(tick, "interval", seconds=1)
+            scheduler.start()
+
+            # Run for five seconds
+            start_time = time.time()
+            while time.time() - start_time < 5.0:
+                await asyncio.sleep(0.1)
+
+
+        asyncio.run(main())
+        """)
 
 
 @importorskip('boto')
@@ -210,7 +214,9 @@ def test_pylsl(pyi_builder):
     pyi_builder.test_source(
         """
         import pylsl
-        print(pylsl.version.__version__)
+        print(f"version: {pylsl.__version__}")
+        print(f"library version: {pylsl.library_version()}")
+        print(f"library info: {pylsl.library_info()}")
         """)
 
 
@@ -1483,13 +1489,22 @@ def test_minecraft_launcher_lib(pyi_builder):
 
 
 @importorskip('moviepy')
-def test_moviepy_editor(pyi_builder):
+def test_moviepy(pyi_builder):
     # `moviepy.editor` tries to access the `moviepy.video.fx` and `moviepy.audio.fx` plugins/modules via the
     # `moviepy.video.fx.all` and `moviepy.video.fx.all` modules, which in turn programmatically import and
     # forward all corresponding submodules.
-    pyi_builder.test_source("""
-        import moviepy.editor
-    """)
+    #
+    # `moviepy.editor` was removed in moviepy 2.x, and now all imports go through `moviepy`. The `moviepy.video.fx.all`
+    # and `moviepy.video.fx.all` modules with their programmatic imports seem to be gone as well... So turn this into
+    # a basic import test with 2.x series.
+    if is_module_satisfies('moviepy >= 2.0.0'):
+        pyi_builder.test_source("""
+            import moviepy
+        """)
+    else:
+        pyi_builder.test_source("""
+            import moviepy.editor
+        """)
 
 
 @importorskip('customtkinter')
@@ -2324,3 +2339,10 @@ def test_h3(pyi_builder):
     pyi_builder.test_source("""
         import h3
     """)
+
+
+@importorskip('selectolax')
+def test_selectolax(pyi_builder):
+    pyi_builder.test_source("""
+        import selectolax
+    """)
